CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_cls.c File Reference

CCL

Macros | Functions
ccl_test_cls.c File Reference
`#include "ccl.h"`
`#include "ctest.h"`
`#include <stdlib.h>`
`#include <stdio.h>`
`#include <math.h>`
`#include <string.h>`

## Macros
#define | SZ_VAL 0.4
#define | CLS_TOLERANCE 1E-3
#define | CLS_FRACTION 1E-3

## Functions
| CTEST_DATA (cls)
| CTEST_SETUP (cls)
| CTEST2 (cls, analytic)
| CTEST2 (cls, histo)

## Macro Definition Documentation

## ◆ CLS_FRACTION

#define CLS_FRACTION 1E-3

## ◆ CLS_TOLERANCE

#define CLS_TOLERANCE 1E-3

## ◆ SZ_VAL

#define SZ_VAL 0.4

## Function Documentation

## ◆ CTEST2() [1/2]

CTEST2 | ( | cls | ,
|  | analytic |
| ) |  |

## ◆ CTEST2() [2/2]

CTEST2 | ( | cls | ,
|  | histo |
| ) |  |

## ◆ CTEST_DATA()

CTEST_DATA | ( | cls |  | ) |

## ◆ CTEST_SETUP()

CTEST_SETUP | ( | cls |  | ) |